﻿using Microsoft.Xaml.Behaviors;
using Syncfusion.UI.Xaml.Grid;
using Syncfusion.UI.Xaml.Grid.Helpers;
using System.Windows.Input;

namespace SfDataGridDemo
{
    public class SfDataGridBehavior : Behavior<SfDataGrid>
    {
        protected override void OnAttached()
        {
            base.OnAttached();
            //Event subscription
            this.AssociatedObject.PreviewKeyDown += OnPreviewKeyDown;
            this.AssociatedObject.SelectionChanged += OnSelectionChanged;
        }

        //Event customization
        private void OnSelectionChanged(object sender, GridSelectionChangedEventArgs e)
        {
            if(e.RemovedItems.Count > 0)
            {
                foreach (var record in e.RemovedItems)
                {
                    //If you need to remove the applied style in SfDataGrid for selection removed records
                    //by calling the UpdateDataRow method to update the style at runtime in SfDataGrid 
                    this.AssociatedObject.UpdateDataRow((record as GridRowInfo).RowIndex);
                }
            }
        }

        //Event customization
        private void OnPreviewKeyDown(object sender, KeyEventArgs e)
        {
            //Here customize based on you scenario
            if ((Keyboard.IsKeyDown(Key.LeftCtrl) || Keyboard.IsKeyDown(Key.RightCtrl)) && e.Key == Key.J)
            {
                foreach(var record in this.AssociatedObject.SelectedItems)
                {
                    //here get RowIndex of the updated cell value
                    var rowIndex = this.AssociatedObject.ResolveToRowIndex(record);
                    //Change the Row Style at runtime by updating the value changed row index in SfDataGrid.
                    this.AssociatedObject.UpdateDataRow(rowIndex);
                }
            }
        }

        protected override void OnDetaching()
        {
            base.OnDetaching();
            this.AssociatedObject.PreviewKeyDown -= OnPreviewKeyDown;
            this.AssociatedObject.SelectionChanged -= OnSelectionChanged;
        }
    }

}
